@@ -52,3 +52,30 @@ regulaFalsi <- function(f, a, b, maxiter=100, tol=.Machine$double.eps^0.5)
 		cat("regulaFalsi stopped without converging.\n")
 	return(list(root = x3, f.root = f3, niter = niter, estim.prec = x1-x2))
 }
+
+
+secant <- function(fun, a, b, ...,
+                   maxiter = 100, tol = .Machine$double.eps^0.5)
+# Secant search for zero of a univariate function
+{
+    fun <- match.fun(fun)
+    f <- function(x) fun(x, ...)
+
+	x1 <- a; x2 <- b
+	f1 <- f(x1); if (abs(f1) <= tol) return(x1)
+	f2 <- f(x2); if (abs(f2) <= tol) return(x1)
+	n <- 0
+	while (n <= maxiter && abs(x2 - x1) > tol) {
+		n <- n+1
+		slope <- (f2 - f1)/(x2 - x1)
+		if (slope == 0) return(root=NA, f.root=NA, iter=n, estim.prec=NA)
+		x3 <- x2 - f2/slope
+		f3 <- f(x3); if (abs(f3) <= tol) break
+		x1 <- x2; f1 <- f2
+		x2 <- x3; f2 <- f3
+	}
+	if (n > maxiter) {
+		warning("Maximum number of iterations 'maxiter' was reached.")
+	}
+	return(list(root=x3, f.root=f3, iter=n, estim.prec=2*abs(x3-x2)))
+}
